import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_codebuild._jsii
import aws_cdk.aws_codepipeline._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecs._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kinesis._jsii
import aws_cdk.aws_kinesisfirehose._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sns_subscriptions._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.aws_stepfunctions._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-events-targets",
    "1.147.0",
    __name__[0:-6],
    "aws-events-targets@1.147.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
